import astropayments
from astropayments import run_call


def post(data={}):
	"""Calls /invoices/{invoice_key}/send
	Update a invoice within the database

	Args:
		data (dict) contents:
			invoice_key (str) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'invoice_key' in data:
		raise Exception('invoice_key required for invoices.send.post()')

	path='/invoices/' + data['invoice_key'] + '/send'
	return run_call('post',path,data,params)



import astropayments
from astropayments import run_call


def post(data={}):
	"""Calls /paymentengine/payrequests
	Start a new transaction on device

	Args:
		data (dict) PayRequest

	Returns:
		Dictionary PayRequestStatus
	"""
	params={}
	path='/paymentengine/payrequests'
	return run_call('post',path,data,params)

def get(data={}):
	"""Calls /paymentengine/payrequests/{requestkey}
	Retreive status of an existing payment request.

	Args:
		data (dict) contents:
			requestkey (str) required

	Returns:
		Dictionary PayRequestStatus
	"""
	params={}
	if not 'requestkey' in data:
		raise Exception('requestkey required for paymentengine.payrequests.get()')

	path='/paymentengine/payrequests'+ '/' + data['requestkey']
	return run_call('get',path,data,params)

def delete(data={}):
	"""Calls /paymentengine/payrequests/{requestkey}
	Cancel a payment request.

	Args:
		data (dict) contents:
			requestkey (str) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'requestkey' in data:
		raise Exception('requestkey required for paymentengine.payrequests.delete()')

	path='/paymentengine/payrequests'+ '/' + data['requestkey']
	return run_call('delete',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /batches/current/transactions
	Retrieves transactin detail for the currently open batch.

	Args:
		data (dict) contents:
			limit (str) optional
			offset (str) optional
			return_bin (str) optional

	Returns:
		Dictionary BatchTransactions
	"""
	params={}
	if 'limit' in data:
		params['limit']=data['limit']
	if 'offset' in data:
		params['offset']=data['offset']
	if 'return_bin' in data:
		params['return_bin']=data['return_bin']

	path='/batches/current/transactions'
	return run_call('get',path,data,params)



import astropayments
from astropayments import run_call


def post(data={}):
	"""Calls /batches/current/close
	Closes the currently open batch

	Returns:
		Dictionary BatchSummary
	"""
	params={}
	path='/batches/current/close'
	return run_call('post',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /invoices/nextnum
	Next default invoice number

	Returns:
		String
	"""
	params={}
	path='/invoices/nextnum'
	return run_call('get',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /invoices/{invoice_key}/payments
	Retreive details of a invoice in database

	Args:
		data (dict) contents:
			invoice_key (str) required

	Returns:
		Dictionary InvoicePaymentList
	"""
	params={}
	if 'limit' in data:
		params['limit']=data['limit']
	if 'offset' in data:
		params['offset']=data['offset']

	if not 'invoice_key' in data:
		raise Exception('invoice_key required for invoices.payments.get()')

	path='/invoices/' + data['invoice_key'] + '/payments'
	return run_call('get',path,data,params)



import astropayments
from astropayments import run_call


def post(data={}):
	"""Calls /customers/enable
	Enables a customer.

	Args:
		data (dict) Key

	Returns:
		Dictionary Status
	"""
	params={}
	path='/customers/enable'
	return run_call('post',path,data,params)



import json
import requests
from requests.auth import HTTPBasicAuth
import time
import random
import string
import hashlib, binascii
import astropayments
from astropayments import mockhandler

api_user='test'
api_pass='test'
base_path='https://api.goastro.com/api/v2'
local_test=False;

def encrypt_string(hash_string):
    """
    Creates sha256 hash_string, not intended to be called directly
    """
    sha_signature = \
        hashlib.sha256(hash_string.encode()).hexdigest()
    return sha_signature

def set_authentication(key,pin):
    """
    Sets authentication for connecting to gateway
    Input: API Key and API pin generated on gateway account
    Output: True
    """
    seed = ''.join([random.choice(string.ascii_letters + string.digits) for n in range(32)])
    clear = key + seed + pin
    hashed = encrypt_string(clear)
    global api_user
    api_user = key
    global api_pass
    api_pass = 's2/' + seed + '/' + hashed
    return True
    

def run_call(type,end_path,data={},params={}):
    """
    Sends api calls to gateway, not intended to be called directly.
    """
    if api_user=='test' or api_pass=='test':
        raise Exception('Please run set_authentication before attempting to run api calls.')
    first=True
    for field,value in params.items():
        if first:
            end_path = end_path + '?' + field + '=' + value
            first=False
        else:
            end_path = end_path + '&' + field + '=' + value
    full_path = base_path+end_path
    
    if(local_test):
        return json.loads(mockhandler.mock_call(type,full_path,json.dumps(data)))
    
    if type=='get':
        response=requests.get(full_path,auth=HTTPBasicAuth(api_user,api_pass))
    elif type=='post':
        response=requests.post(full_path,auth=HTTPBasicAuth(api_user,api_pass),json=data)
    elif type=='put':
        response=requests.put(full_path,auth=HTTPBasicAuth(api_user,api_pass),json=data)
    elif type=='delete':
        response=requests.delete(full_path,auth=HTTPBasicAuth(api_user,api_pass))
    else:
        raise Exception('Unexpected call type, please contact support')
    if response:
        return response.json()
    else:
        raise Exception(f'Unexpected response {response}')
        


import astropayments
from astropayments import run_call


def delete(data={}):
	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}/billing_schedule_rules/bulk
	Delete a existing customer billing rule

	Args:
		data (dict) contents:
			Keys (list) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.billing_schedules.billing_schedule_rules.bulk.delete()')

	if not 'billing_schedule_key' in data:
		raise Exception('billing_schedule_key required for customers.billing_schedules.billing_schedule_rules.bulk.delete()')

	path='/customers/' + data['custkey'] + '/billing_schedules/' + data['billing_schedule_key'] + '/billing_schedule_rules/bulk'
	data_list = data['Keys']
	return run_call('delete',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /batches/{batch_key}/transactions
	Retrieves transactin detail for a specific batch.

	Args:
		data (dict) contents:
			batch_key (str) required

	Returns:
		Dictionary BatchTransactions
	"""
	params={}
	if 'limit' in data:
		params['limit']=data['limit']
	if 'offset' in data:
		params['offset']=data['offset']
	if 'return_bin' in data:
		params['return_bin']=data['return_bin']

	if not 'batch_key' in data:
		raise Exception('batch_key required for batches.transactions.get()')

	path='/batches/' + data['batch_key'] + '/transactions'
	return run_call('get',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}/billing_schedule_rules
	Gets rules for a specific schedule from a customer

	If billing_rule_key is included:
	Gets rules for a specific schedule from a customer

	Args:
		data (dict) contents:
			billing_rule_key (str) optional

	Returns:
		Dictionary CustomerRule

	Returns:
		Dictionary CustomerRuleList
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.billing_schedules.billing_schedule_rules.get()')

	if not 'billing_schedule_key' in data:
		raise Exception('billing_schedule_key required for customers.billing_schedules.billing_schedule_rules.get()')

	path='/customers/' + data['custkey'] + '/billing_schedules/' + data['billing_schedule_key'] + '/billing_schedule_rules'
	if 'billing_rule_key' in data:
		path = path + '/' + data['billing_rule_key']
	return run_call('get',path,data,params)

def delete(data={}):
	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}/billing_schedule_rules/{billing_rule_key}
	Delete a existing customer billing rule

	Args:
		data (dict) contents:
			custkey (str) required
			billing_schedule_key (str) required
			billing_rule_key (str) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.billing_schedules.billing_schedule_rules.delete()')

	if not 'billing_schedule_key' in data:
		raise Exception('billing_schedule_key required for customers.billing_schedules.billing_schedule_rules.delete()')

	if not 'billing_rule_key' in data:
		raise Exception('billing_rule_key required for customers.billing_schedules.billing_schedule_rules.delete()')

	path='/customers/' + data['custkey'] + '/billing_schedules/' + data['billing_schedule_key'] + '/billing_schedule_rules'+ '/' + data['billing_rule_key']
	return run_call('delete',path,data,params)

def put(data={}):
	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}/billing_schedule_rules/{billing_rule_key}
	Gets rules for a specific schedule from a customer

	Args:
		data (dict) contents:
			custkey (str) required
			billing_schedule_key (str) required
			billing_rule_key (str) required
			Also can contain all fields from CustomerRule

	Returns:
		Dictionary CustomerRule
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.billing_schedules.billing_schedule_rules.put()')

	if not 'billing_schedule_key' in data:
		raise Exception('billing_schedule_key required for customers.billing_schedules.billing_schedule_rules.put()')

	if not 'billing_rule_key' in data:
		raise Exception('billing_rule_key required for customers.billing_schedules.billing_schedule_rules.put()')

	path='/customers/' + data['custkey'] + '/billing_schedules/' + data['billing_schedule_key'] + '/billing_schedule_rules'+ '/' + data['billing_rule_key']
	return run_call('put',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /paymentengine/devices/{devicekey}/settings
	Get a devices settings

	Args:
		data (dict) contents:
			devicekey (str) required

	Returns:
		Dictionary DeviceSettings
	"""
	params={}
	if not 'devicekey' in data:
		raise Exception('devicekey required for paymentengine.devices.settings.get()')

	path='/paymentengine/devices/' + data['devicekey'] + '/settings'
	return run_call('get',path,data,params)

def put(data={}):
	"""Calls /paymentengine/devices/{devicekey}/settings
	Register a device

	Args:
		data (dict) contents:
			devicekey (str) required
			Also can contain all fields from DeviceSettings

	Returns:
		Dictionary DeviceResponse
	"""
	params={}
	if not 'devicekey' in data:
		raise Exception('devicekey required for paymentengine.devices.settings.put()')

	path='/paymentengine/devices/' + data['devicekey'] + '/settings'
	return run_call('put',path,data,params)



import astropayments
from astropayments import run_call


def post(data={}):
	"""Calls /tokens
	Generate a credit card token

	Args:
		data (dict) TokenRequest

	Returns:
		Dictionary TokenResponse
	"""
	params={}
	path='/tokens'
	return run_call('post',path,data,params)

def get(data={}):
	"""Calls /tokens/{cardref}
	Retrieve a specific credit card token.

	Args:
		data (dict) contents:
			cardref (str) required

	Returns:
		Dictionary Token
	"""
	params={}
	if not 'cardref' in data:
		raise Exception('cardref required for tokens.get()')

	path='/tokens'+ '/' + data['cardref']
	return run_call('get',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /paymentengine/devices
	Gets a list of registered devices

	If devicekey is included:
	Get a devices details

	Args:
		data (dict) contents:
			limit (str) optional
			offset (str) optional

	Returns:
		Dictionary DeviceResponse

	Returns:
		Dictionary DeviceList
	"""
	params={}
	path='/paymentengine/devices'
	if 'devicekey' in data:
		path = path + '/' + data['devicekey']
	if 'limit' in data:
		params['limit']=data['limit']
	if 'offset' in data:
		params['offset']=data['offset']

	return run_call('get',path,data,params)

def post(data={}):
	"""Calls /paymentengine/devices
	Register a device

	Args:
		data (dict) DeviceRequest

	Returns:
		Dictionary DeviceResponse
	"""
	params={}
	path='/paymentengine/devices'
	return run_call('post',path,data,params)

def delete(data={}):
	"""Calls /paymentengine/devices/{devicekey}
	Unregisters a device

	Args:
		data (dict) contents:
			devicekey (str) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'devicekey' in data:
		raise Exception('devicekey required for paymentengine.devices.delete()')

	path='/paymentengine/devices'+ '/' + data['devicekey']
	return run_call('delete',path,data,params)

def put(data={}):
	"""Calls /paymentengine/devices/{devicekey}
	Register a device

	Args:
		data (dict) contents:
			devicekey (str) required
			Also can contain all fields from DeviceRequest

	Returns:
		Dictionary DeviceResponse
	"""
	params={}
	if not 'devicekey' in data:
		raise Exception('devicekey required for paymentengine.devices.put()')

	path='/paymentengine/devices'+ '/' + data['devicekey']
	return run_call('put',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /transactions/{trankey}/receipts/{receipt_key}
	Retrieve receipt for specific transaction.

	Args:
		data (dict) contents:
			trankey (str) required
			receipt_key (str) required

	Returns:
		String
	"""
	params={}
	if not 'trankey' in data:
		raise Exception('trankey required for transactions.receipts.get()')

	if not 'receipt_key' in data:
		raise Exception('receipt_key required for transactions.receipts.get()')

	path='/transactions/' + data['trankey'] + '/receipts'+ '/' + data['receipt_key']
	return run_call('get',path,data,params)



"""
For support please email integrations@goastro.com
"""

from .api import run_call,set_authentication
from .batches import *
from .batches.current import *
from .batches.transactions import *
from .batches.current.transactions import *
from .batches.current.close import *
from .customers import *
from .customers.enable import *
from .customers.disable import *
from .customers.billing_schedules import *
from .customers.payment_methods import *
from .customers.transactions import *
from .customers.billing_schedules.billing_schedule_rules import *
from .customers.billing_schedules.billing_schedule_rules.bulk import *
from .invoices import *
from .invoices.bulk import *
from .invoices.defaults import *
from .invoices.nextnum import *
from .invoices.columns import *
from .invoices.send import *
from .invoices.cancel import *
from .invoices.payments import *
from .invoices.bulk.send import *
from .paymentengine.devices import *
from .paymentengine.payrequests import *
from .paymentengine.devices.settings import *
from .paymentengine.devices.terminal_config import *
from .paymentengine.devices.kick import *
from .products import *
from .products.categories import *
from .tokens import *
from .transactions import *
from .transactions.send import *
from .transactions.receipts import *


import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /batches/current
	Retrieves the currently open batch.

	Returns:
		Dictionary BatchDetails
	"""
	params={}
	path='/batches/current'
	return run_call('get',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /customers/{custkey}/billing_schedules
	Gets customers billing schedules

	If billing_schedule_key is included:
	Gets specific schedule from a customer

	Args:
		data (dict) contents:
			billing_schedule_key (str) optional

	Returns:
		Dictionary CustomerSchedule

	Returns:
		Dictionary CustomerScheduleList
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.billing_schedules.get()')

	path='/customers/' + data['custkey'] + '/billing_schedules'
	if 'billing_schedule_key' in data:
		path = path + '/' + data['billing_schedule_key']
	return run_call('get',path,data,params)

def post(data={}):
	"""Calls /customers/{custkey}/billing_schedules
	Add billing schedules to customer

	Args:
		data (dict) contents:
			CustomerSchedules (list) required

	Returns:
		List of CustomerSchedules
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.billing_schedules.post()')

	path='/customers/' + data['custkey'] + '/billing_schedules'
	data_list = data['CustomerSchedules']
	return run_call('post',path,data,params)

def delete(data={}):
	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}
	Delete a existing customer

	Args:
		data (dict) contents:
			custkey (str) required
			billing_schedule_key (str) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.billing_schedules.delete()')

	if not 'billing_schedule_key' in data:
		raise Exception('billing_schedule_key required for customers.billing_schedules.delete()')

	path='/customers/' + data['custkey'] + '/billing_schedules'+ '/' + data['billing_schedule_key']
	return run_call('delete',path,data,params)

def put(data={}):
	"""Calls /customers/{custkey}/billing_schedules/{billing_schedule_key}
	Update a customers billing schedule

	Args:
		data (dict) contents:
			custkey (str) required
			billing_schedule_key (str) required
			Also can contain all fields from CustomerSchedule

	Returns:
		Dictionary CustomerSchedule
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.billing_schedules.put()')

	if not 'billing_schedule_key' in data:
		raise Exception('billing_schedule_key required for customers.billing_schedules.put()')

	path='/customers/' + data['custkey'] + '/billing_schedules'+ '/' + data['billing_schedule_key']
	return run_call('put',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /transactions
	Gets a list of transactions

	If trankey is included:
	Retrieve a specific transaction.

	Args:
		data (dict) contents:
			limit (str) optional
			offset (str) optional
			fuzzy (str) optional

	Returns:
		Dictionary Transaction

	Returns:
		Dictionary TransactionList
	"""
	params={}
	path='/transactions'
	if 'trankey' in data:
		path = path + '/' + data['trankey']
	if 'limit' in data:
		params['limit']=data['limit']
	if 'offset' in data:
		params['offset']=data['offset']
	if 'fuzzy' in data:
		params['fuzzy']=data['fuzzy']

	return run_call('get',path,data,params)

def post(data={}):
	"""Calls /transactions
	Run a transaction

	Args:
		data (dict) TransactionRequest

	Returns:
		Dictionary TransactionResponse
	"""
	params={}
	path='/transactions'
	return run_call('post',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /customers/{custkey}/payment_methods
	Delete a existing customer billing rule

	If paymethod_key is included:
	Delete a existing customer billing rule

	Args:
		data (dict) contents:
			paymethod_key (str) optional

	Returns:
		Dictionary CustomerPaymentMethod

	Returns:
		Dictionary CustomerPaymentMethodList
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.payment_methods.get()')

	path='/customers/' + data['custkey'] + '/payment_methods'
	if 'paymethod_key' in data:
		path = path + '/' + data['paymethod_key']
	return run_call('get',path,data,params)

def post(data={}):
	"""Calls /customers/{custkey}/payment_methods
	Add an array of new payment methods to an existing customer

	Args:
		data (dict) contents:
			CustomerPaymentMethodRequests (list) required

	Returns:
		List of CustomerPaymentMethods
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.payment_methods.post()')

	path='/customers/' + data['custkey'] + '/payment_methods'
	data_list = data['CustomerPaymentMethodRequests']
	return run_call('post',path,data,params)

def delete(data={}):
	"""Calls /customers/{custkey}/payment_methods/{paymethod_key}
	Delete a existing customer billing rule

	Args:
		data (dict) contents:
			custkey (str) required
			paymethod_key (str) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.payment_methods.delete()')

	if not 'paymethod_key' in data:
		raise Exception('paymethod_key required for customers.payment_methods.delete()')

	path='/customers/' + data['custkey'] + '/payment_methods'+ '/' + data['paymethod_key']
	return run_call('delete',path,data,params)

def put(data={}):
	"""Calls /customers/{custkey}/payment_methods/{paymethod_key}
	Update an existing customer payment method

	Args:
		data (dict) contents:
			custkey (str) required
			paymethod_key (str) required
			Also can contain all fields from CustomerPaymentMethodRequest

	Returns:
		Dictionary CustomerPaymentMethod
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.payment_methods.put()')

	if not 'paymethod_key' in data:
		raise Exception('paymethod_key required for customers.payment_methods.put()')

	path='/customers/' + data['custkey'] + '/payment_methods'+ '/' + data['paymethod_key']
	return run_call('put',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /invoices/defaults
	Get invoice defaults

	Returns:
		Dictionary Defaults
	"""
	params={}
	path='/invoices/defaults'
	return run_call('get',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /customers
	Gets a list of your customers

	If custkey is included:
	Retrieve a existing customer

	Args:
		data (dict) contents:
			limit (str) optional
			offset (str) optional

	Returns:
		Dictionary Customer

	Returns:
		Dictionary CustomerList
	"""
	params={}
	path='/customers'
	if 'custkey' in data:
		path = path + '/' + data['custkey']
	if 'limit' in data:
		params['limit']=data['limit']
	if 'offset' in data:
		params['offset']=data['offset']

	return run_call('get',path,data,params)

def post(data={}):
	"""Calls /customers
	Save a customer to your customer database

	Args:
		data (dict) CustomerRequest

	Returns:
		Dictionary Customer
	"""
	params={}
	path='/customers'
	return run_call('post',path,data,params)

def delete(data={}):
	"""Calls /customers/{custkey}
	Delete a existing customer

	Args:
		data (dict) contents:
			custkey (str) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.delete()')

	path='/customers'+ '/' + data['custkey']
	return run_call('delete',path,data,params)

def put(data={}):
	"""Calls /customers/{custkey}
	Updates a existing customer

	Args:
		data (dict) contents:
			custkey (str) required
			Also can contain all fields from CustomerRequest

	Returns:
		Dictionary Customer
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.put()')

	path='/customers'+ '/' + data['custkey']
	return run_call('put',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /customers/{custkey}/transactions
	Retrieve a existing customer

	Args:
		data (dict) contents:
			custkey (str) required

	Returns:
		Dictionary TransactionList
	"""
	params={}
	if not 'custkey' in data:
		raise Exception('custkey required for customers.transactions.get()')

	path='/customers/' + data['custkey'] + '/transactions'
	return run_call('get',path,data,params)



import astropayments
from astropayments import run_call


def post(data={}):
	"""Calls /transactions/{trankey}/send
	Email receipt for specific transaction.

	Args:
		data (dict) contents:
			trankey (str) required
			Also can contain all fields from SendReceiptRequest

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'trankey' in data:
		raise Exception('trankey required for transactions.send.post()')

	path='/transactions/' + data['trankey'] + '/send'
	return run_call('post',path,data,params)



import astropayments
from astropayments import run_call


def post(data={}):
	"""Calls /paymentengine/devices/{devicekey}/kick
	Kick a device offline

	Args:
		data (dict) contents:
			devicekey (str) required

	Returns:
		Dictionary DeviceResponse
	"""
	params={}
	if not 'devicekey' in data:
		raise Exception('devicekey required for paymentengine.devices.kick.post()')

	path='/paymentengine/devices/' + data['devicekey'] + '/kick'
	return run_call('post',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /invoices
	Get a list of invoices

	If invoice_key is included:
	Retreive details of a invoice in database

	Args:
		data (dict) contents:
			limit (str) optional
			offset (str) optional

	Returns:
		Dictionary InvoiceResponse

	Returns:
		Dictionary InvoiceList
	"""
	params={}
	path='/invoices'
	if 'invoice_key' in data:
		path = path + '/' + data['invoice_key']
	if 'limit' in data:
		params['limit']=data['limit']
	if 'offset' in data:
		params['offset']=data['offset']

	return run_call('get',path,data,params)

def post(data={}):
	"""Calls /invoices
	Generate a credit card token

	Args:
		data (dict) InvoiceRequest

	Returns:
		Dictionary InvoiceResponse
	"""
	params={}
	path='/invoices'
	return run_call('post',path,data,params)

def delete(data={}):
	"""Calls /invoices/{invoice_key}
	Delete a invoice from the database

	Args:
		data (dict) contents:
			invoice_key (str) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'invoice_key' in data:
		raise Exception('invoice_key required for invoices.delete()')

	path='/invoices'+ '/' + data['invoice_key']
	return run_call('delete',path,data,params)

def put(data={}):
	"""Calls /invoices/{invoice_key}
	Update a invoice within the database

	Args:
		data (dict) contents:
			invoice_key (str) required
			Also can contain all fields from InvoiceRequest

	Returns:
		Dictionary InvoiceResponse
	"""
	params={}
	if not 'invoice_key' in data:
		raise Exception('invoice_key required for invoices.put()')

	path='/invoices'+ '/' + data['invoice_key']
	return run_call('put',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /batches
	Retrieves a list of batches associated with the account

	If batch_key is included:
	Retrieves a specific batch.

	Args:
		data (dict) contents:
			limit (str) optional
			offset (str) optional
			openedlt (str) optional
			openedgt (str) optional
			closedlt (str) optional
			closedgt (str) optional
			openedle (str) optional
			openedge (str) optional
			closedle (str) optional
			closedge (str) optional

	Returns:
		Dictionary BatchDetails

	Returns:
		Dictionary BatchList
	"""
	params={}
	path='/batches'
	if 'batch_key' in data:
		path = path + '/' + data['batch_key']
	if 'limit' in data:
		params['limit']=data['limit']
	if 'offset' in data:
		params['offset']=data['offset']
	if 'openedlt' in data:
		params['openedlt']=data['openedlt']
	if 'openedgt' in data:
		params['openedgt']=data['openedgt']
	if 'closedlt' in data:
		params['closedlt']=data['closedlt']
	if 'closedgt' in data:
		params['closedgt']=data['closedgt']
	if 'openedle' in data:
		params['openedle']=data['openedle']
	if 'openedge' in data:
		params['openedge']=data['openedge']
	if 'closedle' in data:
		params['closedle']=data['closedle']
	if 'closedge' in data:
		params['closedge']=data['closedge']

	return run_call('get',path,data,params)



import re

mock_response = '{"Response":"No Response Set"}'
mock_path = ''
mock_method = ''
mock_request = ''

def mock_call(method,path,request):
    """
    Handles local testing, not intended to be called directly.
    """
    global mock_method 
    mock_method = method
    global mock_path
    mock_path = path
    pat = re.compile('"number":"([0-9]+)"')
    matches = pat.findall(request)
    if matches.count('4000100011112224') != len(matches):
        raise Exception('Please only use test card 4000100011112224 with the mockhandler')
    global mock_request
    mock_request = request
    global mock_response
    return mock_response
    


import astropayments
from astropayments import run_call


def post(data={}):
	"""Calls /invoices/bulk/send
	Get invoice defaults

	Args:
		data (dict) contents:
			Keys (list) required

	Returns:
		Dictionary Status
	"""
	params={}
	path='/invoices/bulk/send'
	data_list = data['Keys']
	return run_call('post',path,data,params)



import astropayments
from astropayments import run_call


def get(data={}):
	"""Calls /products
	Retreive a list of products in database

	If product_key is included:
	Retreive details of a product in database

	Args:
		data (dict) contents:
			limit (str) optional
			offset (str) optional

	Returns:
		Dictionary ProductResponse

	Returns:
		Dictionary ProductList
	"""
	params={}
	path='/products'
	if 'product_key' in data:
		path = path + '/' + data['product_key']
	if 'limit' in data:
		params['limit']=data['limit']
	if 'offset' in data:
		params['offset']=data['offset']

	return run_call('get',path,data,params)

def post(data={}):
	"""Calls /products
	Generate a credit card token

	Args:
		data (dict) ProductRequest

	Returns:
		Dictionary ProductResponse
	"""
	params={}
	path='/products'
	return run_call('post',path,data,params)

def delete(data={}):
	"""Calls /products/{product_key}
	Delete a product from the database

	Args:
		data (dict) contents:
			product_key (str) required

	Returns:
		Dictionary Status
	"""
	params={}
	if not 'product_key' in data:
		raise Exception('product_key required for products.delete()')

	path='/products'+ '/' + data['product_key']
	return run_call('delete',path,data,params)

def put(data={}):
	"""Calls /products/{product_key}
	Update a product within the database

	Args:
		data (dict) contents:
			product_key (str) required
			Also can contain all fields from ProductRequest

	Returns:
		Dictionary ProductResponse
	"""
	params={}
	if not 'product_key' in data:
		raise Exception('product_key required for products.put()')

	path='/products'+ '/' + data['product_key']
	return run_call('put',path,data,params)
